@@ -20,8 +20,9 @@ def status():
 @click.option('-url', type=str, help='Paste your link of the repo',required=False)
 @click.option('-m',type=str,help = "Commit message ")
 @click.option('-b',type=str, help ="Branch name for checkout")
-def pushbranch(m,b,**url):
-    click.echo(gf.push_branch(m,b,**url))
+
+def pushbranch(m,b,url):
+    click.echo(gf.push_branch(m,b,url))
 
 @cli.command()
 def remote():
